==> google-cloud-sdk-483.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/aiplatform_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .content import (
    Blob,
    Candidate,
    Citation,
    CitationMetadata,
    Content,
    FileData,
    GenerationConfig,
    GroundingMetadata,
    Part,
    SafetyRating,
    SafetySetting,
    SearchEntryPoint,
    VideoMetadata,
    HarmCategory,
)
from .explanation import (
    Attribution,
    BlurBaselineConfig,
    Examples,
    ExamplesOverride,
    ExamplesRestrictionsNamespace,
    Explanation,
    ExplanationMetadataOverride,
    ExplanationParameters,
    ExplanationSpec,
    ExplanationSpecOverride,
    FeatureNoiseSigma,
    IntegratedGradientsAttribution,
    ModelExplanation,
    Neighbor,
    Presets,
    SampledShapleyAttribution,
    SmoothGradConfig,
    XraiAttribution,
)
from .explanation_metadata import (
    ExplanationMetadata,
)
from .io import (
    AvroSource,
    BigQueryDestination,
    BigQuerySource,
    ContainerRegistryDestination,
    CsvDestination,
    CsvSource,
    GcsDestination,
    GcsSource,
    TFRecordDestination,
)
from .openapi import (
    Schema,
    Type,
)
from .prediction_service import (
    CountTokensRequest,
    CountTokensResponse,
    DirectPredictRequest,
    DirectPredictResponse,
    DirectRawPredictRequest,
    DirectRawPredictResponse,
    ExplainRequest,
    ExplainResponse,
    GenerateContentRequest,
    GenerateContentResponse,
    PredictRequest,
    PredictResponse,
    RawPredictRequest,
    StreamDirectPredictRequest,
    StreamDirectPredictResponse,
    StreamDirectRawPredictRequest,
    StreamDirectRawPredictResponse,
    StreamingPredictRequest,
    StreamingPredictResponse,
    StreamingRawPredictRequest,
    StreamingRawPredictResponse,
    StreamRawPredictRequest,
)
from .tool import (
    FunctionCall,
    FunctionCallingConfig,
    FunctionDeclaration,
    FunctionResponse,
    GoogleSearchRetrieval,
    Retrieval,
    Tool,
    ToolConfig,
    VertexAISearch,
)
from .types import (
    BoolArray,
    DoubleArray,
    Int64Array,
    StringArray,
    Tensor,
)

__all__ = (
    'Blob',
    'Candidate',
    'Citation',
    'CitationMetadata',
    'Content',
    'FileData',
    'GenerationConfig',
    'GroundingMetadata',
    'Part',
    'SafetyRating',
    'SafetySetting',
    'SearchEntryPoint',
    'VideoMetadata',
    'HarmCategory',
    'Attribution',
    'BlurBaselineConfig',
    'Examples',
    'ExamplesOverride',
    'ExamplesRestrictionsNamespace',
    'Explanation',
    'ExplanationMetadataOverride',
    'ExplanationParameters',
    'ExplanationSpec',
    'ExplanationSpecOverride',
    'FeatureNoiseSigma',
    'IntegratedGradientsAttribution',
    'ModelExplanation',
    'Neighbor',
    'Presets',
    'SampledShapleyAttribution',
    'SmoothGradConfig',
    'XraiAttribution',
    'ExplanationMetadata',
    'AvroSource',
    'BigQueryDestination',
    'BigQuerySource',
    'ContainerRegistryDestination',
    'CsvDestination',
    'CsvSource',
    'GcsDestination',
    'GcsSource',
    'TFRecordDestination',
    'Schema',
    'Type',
    'CountTokensRequest',
    'CountTokensResponse',
    'DirectPredictRequest',
    'DirectPredictResponse',
    'DirectRawPredictRequest',
    'DirectRawPredictResponse',
    'ExplainRequest',
    'ExplainResponse',
    'GenerateContentRequest',
    'GenerateContentResponse',
    'PredictRequest',
    'PredictResponse',
    'RawPredictRequest',
    'StreamDirectPredictRequest',
    'StreamDirectPredictResponse',
    'StreamDirectRawPredictRequest',
    'StreamDirectRawPredictResponse',
    'StreamingPredictRequest',
    'StreamingPredictResponse',
    'StreamingRawPredictRequest',
    'StreamingRawPredictResponse',
    'StreamRawPredictRequest',
    'FunctionCall',
    'FunctionCallingConfig',
    'FunctionDeclaration',
    'FunctionResponse',
    'GoogleSearchRetrieval',
    'Retrieval',
    'Tool',
    'ToolConfig',
    'VertexAISearch',
    'BoolArray',
    'DoubleArray',
    'Int64Array',
    'StringArray',
    'Tensor',
)

==> google-cloud-sdk-508.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/aiplatform_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .api_auth import (
    ApiAuth,
)
from .content import (
    Blob,
    Candidate,
    Citation,
    CitationMetadata,
    Content,
    FileData,
    GenerationConfig,
    GroundingChunk,
    GroundingMetadata,
    GroundingSupport,
    LogprobsResult,
    Part,
    PrebuiltVoiceConfig,
    RetrievalMetadata,
    SafetyRating,
    SafetySetting,
    SearchEntryPoint,
    Segment,
    SpeechConfig,
    VideoMetadata,
    VoiceConfig,
    HarmCategory,
)
from .explanation import (
    Attribution,
    BlurBaselineConfig,
    Examples,
    ExamplesOverride,
    ExamplesRestrictionsNamespace,
    Explanation,
    ExplanationMetadataOverride,
    ExplanationParameters,
    ExplanationSpec,
    ExplanationSpecOverride,
    FeatureNoiseSigma,
    IntegratedGradientsAttribution,
    ModelExplanation,
    Neighbor,
    Presets,
    SampledShapleyAttribution,
    SmoothGradConfig,
    XraiAttribution,
)
from .explanation_metadata import (
    ExplanationMetadata,
)
from .io import (
    AvroSource,
    BigQueryDestination,
    BigQuerySource,
    ContainerRegistryDestination,
    CsvDestination,
    CsvSource,
    DirectUploadSource,
    GcsDestination,
    GcsSource,
    GoogleDriveSource,
    JiraSource,
    SharePointSources,
    SlackSource,
    TFRecordDestination,
)
from .openapi import (
    Schema,
    Type,
)
from .prediction_service import (
    ChatCompletionsRequest,
    CountTokensRequest,
    CountTokensResponse,
    DirectPredictRequest,
    DirectPredictResponse,
    DirectRawPredictRequest,
    DirectRawPredictResponse,
    ExplainRequest,
    ExplainResponse,
    FetchPredictOperationRequest,
    GenerateContentRequest,
    GenerateContentResponse,
    PredictLongRunningRequest,
    PredictRequest,
    PredictResponse,
    RawPredictRequest,
    StreamDirectPredictRequest,
    StreamDirectPredictResponse,
    StreamDirectRawPredictRequest,
    StreamDirectRawPredictResponse,
    StreamingPredictRequest,
    StreamingPredictResponse,
    StreamingRawPredictRequest,
    StreamingRawPredictResponse,
    StreamRawPredictRequest,
)
from .tool import (
    DynamicRetrievalConfig,
    FunctionCall,
    FunctionCallingConfig,
    FunctionDeclaration,
    FunctionResponse,
    GoogleSearchRetrieval,
    RagRetrievalConfig,
    Retrieval,
    Tool,
    ToolConfig,
    VertexAISearch,
    VertexRagStore,
)
from .types import (
    BoolArray,
    DoubleArray,
    Int64Array,
    StringArray,
    Tensor,
)

__all__ = (
    'ApiAuth',
    'Blob',
    'Candidate',
    'Citation',
    'CitationMetadata',
    'Content',
    'FileData',
    'GenerationConfig',
    'GroundingChunk',
    'GroundingMetadata',
    'GroundingSupport',
    'LogprobsResult',
    'Part',
    'PrebuiltVoiceConfig',
    'RetrievalMetadata',
    'SafetyRating',
    'SafetySetting',
    'SearchEntryPoint',
    'Segment',
    'SpeechConfig',
    'VideoMetadata',
    'VoiceConfig',
    'HarmCategory',
    'Attribution',
    'BlurBaselineConfig',
    'Examples',
    'ExamplesOverride',
    'ExamplesRestrictionsNamespace',
    'Explanation',
    'ExplanationMetadataOverride',
    'ExplanationParameters',
    'ExplanationSpec',
    'ExplanationSpecOverride',
    'FeatureNoiseSigma',
    'IntegratedGradientsAttribution',
    'ModelExplanation',
    'Neighbor',
    'Presets',
    'SampledShapleyAttribution',
    'SmoothGradConfig',
    'XraiAttribution',
    'ExplanationMetadata',
    'AvroSource',
    'BigQueryDestination',
    'BigQuerySource',
    'ContainerRegistryDestination',
    'CsvDestination',
    'CsvSource',
    'DirectUploadSource',
    'GcsDestination',
    'GcsSource',
    'GoogleDriveSource',
    'JiraSource',
    'SharePointSources',
    'SlackSource',
    'TFRecordDestination',
    'Schema',
    'Type',
    'ChatCompletionsRequest',
    'CountTokensRequest',
    'CountTokensResponse',
    'DirectPredictRequest',
    'DirectPredictResponse',
    'DirectRawPredictRequest',
    'DirectRawPredictResponse',
    'ExplainRequest',
    'ExplainResponse',
    'FetchPredictOperationRequest',
    'GenerateContentRequest',
    'GenerateContentResponse',
    'PredictLongRunningRequest',
    'PredictRequest',
    'PredictResponse',
    'RawPredictRequest',
    'StreamDirectPredictRequest',
    'StreamDirectPredictResponse',
    'StreamDirectRawPredictRequest',
    'StreamDirectRawPredictResponse',
    'StreamingPredictRequest',
    'StreamingPredictResponse',
    'StreamingRawPredictRequest',
    'StreamingRawPredictResponse',
    'StreamRawPredictRequest',
    'DynamicRetrievalConfig',
    'FunctionCall',
    'FunctionCallingConfig',
    'FunctionDeclaration',
    'FunctionResponse',
    'GoogleSearchRetrieval',
    'RagRetrievalConfig',
    'Retrieval',
    'Tool',
    'ToolConfig',
    'VertexAISearch',
    'VertexRagStore',
    'BoolArray',
    'DoubleArray',
    'Int64Array',
    'StringArray',
    'Tensor',
)
